@@ -80,7 +80,8 @@ namespace boost { namespace math { namespace detail {
          if (a < 0)
          {
             if ((b < a) && (z < -b / 4))
-               return hypergeometric_1F1_from_function_ratio_negative_ab(a, b, z, pol, log_scaling);
+               // Defensive programming: it is *almost* certain that we can never get here, proving that is hard though...
+               return hypergeometric_1F1_from_function_ratio_negative_ab(a, b, z, pol, log_scaling);  // LCOV_EXCL_LINE
             else
             {
                //
@@ -123,6 +124,7 @@ namespace boost { namespace math { namespace detail {
             {
                if (boost::math::policies::digits<T, Policy>() <= 64)
                   return hypergeometric_1F1_from_function_ratio_negative_b_forwards(a, b, z, pol, log_scaling);
+               // LCOV_EXCL_START, what follows is multiprecision only
 #ifndef BOOST_MATH_NO_EXCEPTIONS
                try
 #endif
@@ -138,6 +140,7 @@ namespace boost { namespace math { namespace detail {
                   return hypergeometric_1F1_from_function_ratio_negative_b_forwards(a, b, z, pol, log_scaling);
                }
 #endif
+               // LCOV_EXCL_STOP
             }
             //
             // We could fall back to Tricomi's approximation if we're in the transition zone
@@ -160,6 +163,8 @@ namespace boost { namespace math { namespace detail {
       return hypergeometric_1F1_checked_series_impl(a, b, z, pol, log_scaling);
    }
 
+#if 0
+   // Archived, not used, see comments at call site.
    template <class T>
    bool is_convergent_negative_z_series(const T& a, const T& b, const T& z, const T& b_minus_a)
    {
@@ -180,7 +185,7 @@ namespace boost { namespace math { namespace detail {
          // Double check for divergence when we cross the origin on a and b:
          if (a < 0)
          {
-            T n = 300 - floor(a);
+            T n = 3 - floor(a);
             if (fabs((a + n) * z / ((b + n) * n)) < 1)
             {
                if (b < 0)
@@ -225,7 +230,7 @@ namespace boost { namespace math { namespace detail {
       }
       return false;
    }
-
+#endif
    template <class T>
    inline T cyl_bessel_i_shrinkage_rate(const T& z)
    {
@@ -313,11 +318,7 @@ namespace boost { namespace math { namespace detail {
 
       // undefined result:
       if (!detail::check_hypergeometric_1F1_parameters(a, b))
-         return policies::raise_domain_error<T>(
-            function,
-            "Function is indeterminate for negative integer b = %1%.",
-            b,
-            pol);
+         return policies::raise_domain_error<T>(function, "Function is indeterminate for negative integer b = %1%.", b, pol);
 
       // other checks:
       if (a == -1)
@@ -444,6 +445,12 @@ namespace boost { namespace math { namespace detail {
       {
          if (a == 1)
             return detail::hypergeometric_1F1_pade(b, z, pol);
+#if 0
+         //
+         // Commented out: is_convergent_negative_z_series is fine so far as it goes
+         // but there appear to be no cases that use it, and in extremis, we will
+         // fall through to the series evaluation anyway.
+         //
          if (is_convergent_negative_z_series(a, b, z, b_minus_a))
          {
             if ((boost::math::sign(b_minus_a) == boost::math::sign(b)) && ((b > 0) || (b < -200)))
@@ -462,6 +469,7 @@ namespace boost { namespace math { namespace detail {
                return hypergeometric_1F1_checked_series_impl(a, b, z, pol, log_scaling);
             }
          }
+#endif
          if ((b < 0) && (floor(b) == b))
          {
             // Negative integer b, so a must be a negative integer too.
@@ -673,16 +681,26 @@ namespace boost { namespace math { namespace detail {
 
       while (scale > max_scaling)
       {
+         if((fabs(result) > 1) && (fabs(tools::max_value<T>()) / result <= max_scale_factor))
+            return policies::raise_overflow_error<T>("hypergeometric_1F1_regularized", nullptr, pol);
+         // This is *probably* unreachable:
+         // LCOV_EXCL_START
          result *= max_scale_factor;
          scale -= max_scaling;
+         // LCOV_EXCL_STOP
       }
       while (scale < -max_scaling)
       {
          result /= max_scale_factor;
-     scale += max_scaling;
+         scale += max_scaling;
       }
       if (scale != 0)
-         result *= exp(scale);
+      {
+         scale = exp(scale);
+         if ((scale > 1) && (fabs(result) > 1) && (fabs(tools::max_value<T>() / result) <= scale))
+            return policies::raise_overflow_error<T>("hypergeometric_1F1_regularized", nullptr, pol);
+         result *= scale;
+      }
       return result * result_sign;
    }
 
